==> graylog2-server-4.1.1-sources.jar: org/graylog2/contentpacks/model/entities/AutoValue_LookupTableEntity.java <==
package org.graylog2.contentpacks.model.entities;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.graylog2.contentpacks.model.entities.references.ValueReference;

final class AutoValue_LookupTableEntity extends $AutoValue_LookupTableEntity {
  AutoValue_LookupTableEntity(ValueReference name, ValueReference title, ValueReference description,
      ValueReference cacheName, ValueReference dataAdapterName, ValueReference defaultSingleValue,
      ValueReference defaultSingleValueType, ValueReference defaultMultiValue,
      ValueReference defaultMultiValueType) {
    super(name, title, description, cacheName, dataAdapterName, defaultSingleValue, defaultSingleValueType, defaultMultiValue, defaultMultiValueType);
  }

  @JsonIgnore
  public final ValueReference getName() {
    return name();
  }

  @JsonIgnore
  public final ValueReference getTitle() {
    return title();
  }

  @JsonIgnore
  public final ValueReference getDescription() {
    return description();
  }

  @JsonIgnore
  public final ValueReference getCacheName() {
    return cacheName();
  }

  @JsonIgnore
  public final ValueReference getDataAdapterName() {
    return dataAdapterName();
  }

  @JsonIgnore
  public final ValueReference getDefaultSingleValue() {
    return defaultSingleValue();
  }

  @JsonIgnore
  public final ValueReference getDefaultSingleValueType() {
    return defaultSingleValueType();
  }

  @JsonIgnore
  public final ValueReference getDefaultMultiValue() {
    return defaultMultiValue();
  }

  @JsonIgnore
  public final ValueReference getDefaultMultiValueType() {
    return defaultMultiValueType();
  }
}

==> graylog2-server-5.1.12-sources.jar: org/graylog2/contentpacks/model/entities/AutoValue_LookupTableEntity.java <==
package org.graylog2.contentpacks.model.entities;

import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.annotation.Nullable;
import org.graylog2.contentpacks.model.entities.references.ValueReference;

final class AutoValue_LookupTableEntity extends $AutoValue_LookupTableEntity {
  AutoValue_LookupTableEntity(ValueReference scope, ValueReference name, ValueReference title,
      ValueReference description, ValueReference cacheName, ValueReference dataAdapterName,
      ValueReference defaultSingleValue, ValueReference defaultSingleValueType,
      ValueReference defaultMultiValue, ValueReference defaultMultiValueType) {
    super(scope, name, title, description, cacheName, dataAdapterName, defaultSingleValue, defaultSingleValueType, defaultMultiValue, defaultMultiValueType);
  }

  @JsonIgnore
  @Nullable
  public final ValueReference getScope() {
    return scope();
  }

  @JsonIgnore
  public final ValueReference getName() {
    return name();
  }

  @JsonIgnore
  public final ValueReference getTitle() {
    return title();
  }

  @JsonIgnore
  public final ValueReference getDescription() {
    return description();
  }

  @JsonIgnore
  public final ValueReference getCacheName() {
    return cacheName();
  }

  @JsonIgnore
  public final ValueReference getDataAdapterName() {
    return dataAdapterName();
  }

  @JsonIgnore
  public final ValueReference getDefaultSingleValue() {
    return defaultSingleValue();
  }

  @JsonIgnore
  public final ValueReference getDefaultSingleValueType() {
    return defaultSingleValueType();
  }

  @JsonIgnore
  public final ValueReference getDefaultMultiValue() {
    return defaultMultiValue();
  }

  @JsonIgnore
  public final ValueReference getDefaultMultiValueType() {
    return defaultMultiValueType();
  }
}
